@@ -1,9 +1,14 @@
 #' Distribution evaluation.
 #' 
-#' @aliases inverse.simpson diversity gini chao1
+#' @aliases inverse.simpson diversity gini chao1 gini.simpson
 #' 
 #' @description
-#' Function for evaluating the diversity of species or objects in the given distribution.
+#' Functions for evaluating the diversity of species or objects in the given distribution.
+#' 
+#' Warning!
+#' Functions will check if .data if a distribution of random variable (sum == 1) or not.
+#' To force normalisation and / or to prevent this, set .do.norm to TRUE (do normalisation)
+#' or FALSE (don't do normalisation), respectively.
 #' 
 #' - True diversity, or the effective number of types, refers to the number
 #' of equally-abundant types needed for the average proportional abundance
@@ -20,11 +25,10 @@
 #' has the same income). A Gini coefficient of one (or 100 percents ) expresses maximal inequality
 #' among values (for example where only one person has all the income).
 #' 
-#' - Chao1 estimator is a nonparameteric asymptotic estimator of species richness (number of species in a population).
+#' - The Gini-Simpson index is the probability of interspecific encounter, i.e., probability that two entities
+#' represent different types.
 #' 
-#' Functions will check if .data if a distribution of random variable (sum == 1) or not.
-#' To force normalisation and / or to prevent this, set .do.norm to TRUE (do normalisation)
-#' or FALSE (don't do normalisation), respectively.
+#' - Chao1 estimator is a nonparameteric asymptotic estimator of species richness (number of species in a population).
 #' 
 #' @usage
 #' inverse.simpson(.data, .do.norm = NA, .laplace = 0)
@@ -33,6 +37,8 @@
 #' 
 #' gini(.data, .do.norm = NA, .laplace = 0)
 #' 
+#' gini.simpson(.data, .do.norm = NA, .laplace = 0)
+#' 
 #' chao1(.data)
 #' 
 #' @param .data Numeric vector of values for proportions or for numbers of individuals.
@@ -51,7 +57,7 @@
 #' data(twb)
 #' # Next two are equal calls:
 #' stopifnot(gini(twb[[1]]$Read.count, TRUE, 0) - 0.7609971 < 1e-07)
-#' stopifnot(gini(twb[[1]]$Percentage, FALSE) - 0.7609971 < 1e-07)
+#' stopifnot(gini(twb[[1]]$Read.proportion, FALSE) - 0.7609971 < 1e-07)
 #' stopifnot(chao1(twb[[1]]$Read.count)[1] == 1e+04)
 inverse.simpson <- function (.data, .do.norm = NA, .laplace = 0) {
   .data <- check.distribution(.data, .do.norm, .laplace)
@@ -60,7 +66,15 @@ inverse.simpson <- function (.data, .do.norm = NA, .laplace = 0) {
 
 diversity <- function (.data, .q = 5, .do.norm = NA, .laplace = 0) {
   .data <- check.distribution(.data, .do.norm, .laplace)
-  1 / (sum(.data ^ .q) ^ (1 / (.q - 1)))
+  if (.q == 0) {
+    length(.data)
+  } else if (.q == 1) {
+    1 / prod(.data ^ .data)
+  } else if (.q > 1) {
+    1 / (sum(.data ^ .q) ^ (1 / (.q - 1)))
+  } else {
+    NA
+  }
 }
 
 gini <- function (.data, .do.norm = NA, .laplace = 0) {
@@ -69,6 +83,10 @@ gini <- function (.data, .do.norm = NA, .laplace = 0) {
   1 / n * (n + 1 - 2 * sum((n + 1 - 1:n) * .data) / sum(.data))
 }
 
+gini.simpson <- function (.data, .do.norm = NA, .laplace = 0) {
+  1 - 1 / inverse.simpson(.data, .do.norm, .laplace)
+}
+
 chao1 <- function (.data) {
   counts <- table(.data)
   e <- NA
@@ -122,7 +140,7 @@ chao1 <- function (.data) {
 #' @param .data Data frame or a list with data frames.
 #' @param .step Step's size.
 #' @param .quantile Numeric vector of length 2 with quantiles for confidence intervals.
-#' @param .extrapolation If T than perform extrapolation of all samples to the size of the max one + 200000 reads or barcodes.
+#' @param .extrapolation If N > 0 than perform extrapolation of all samples to the size of the max one +N reads or barcodes.
 #' @param .col Column's name from which choose frequency of each clone.
 #' @param .verbose If T than print progress bar.
 #' 
@@ -144,7 +162,7 @@ chao1 <- function (.data) {
 #' \dontrun{
 #' rarefaction(immdata, .col = "Read.count")
 #' }
-rarefaction <- function (.data, .step = 30000, .quantile = c(.025, .975), .extrapolation = T, .col = 'Barcode.count', .verbose = T) {
+rarefaction <- function (.data, .step = 30000, .quantile = c(.025, .975), .extrapolation = 200000, .col = 'Barcode.count', .verbose = T) {
   if (has.class(.data, 'data.frame')) {
     .data <- list(Data = .data)
   }
@@ -197,7 +215,11 @@ rarefaction <- function (.data, .step = 30000, .quantile = c(.025, .975), .extra
       
       # poisson
       Sind <- sum(sapply(1:length(freqs), function (k) (1 - alphas[k]) * counts[k]))
-      SD <- sqrt(sum(sapply(1:length(freqs), function (k) (1 - alphas[k])^2 * counts[k])) - Sind^2/Sest[1])
+      if (Sest[1] == Sobs) {
+        SD <- 0
+      } else {
+        SD <- sqrt(sum(sapply(1:length(freqs), function (k) (1 - alphas[k])^2 * counts[k])) - Sind^2/Sest[1])
+      }
       t <- Sind - Sobs
       K <- exp(qnorm(.975) * sqrt(log(1 + (SD / t)^2)))
       lo <- Sobs + t*K
@@ -208,12 +230,17 @@ rarefaction <- function (.data, .step = 30000, .quantile = c(.025, .975), .extra
       res
     }))
 
-    if (.extrapolation) {
-      sizes <- seq(sum(.data[[i]][, .col]), 200000 + max(sapply(.data, function (x) sum(x[, .col]))), .step)
+    if (.extrapolation > 0) {
+      sizes <- seq(sum(.data[[i]][, .col]), .extrapolation + max(sapply(.data, function (x) sum(x[, .col]))), .step)
       if (length(sizes) != 1) {        
         ex.res <- t(sapply(sizes, function (sz) {
           f0 <- Sest[1] - Sobs
-          Sind <- Sobs + f0 * (1 - exp(-(sz - n)/n * counts['1'] / f0))
+          f1 <- counts['1']
+          if (is.na(f1) || f0 == 0) {
+            Sind <- Sobs
+          } else {
+            Sind <- Sobs + f0 * (1 - exp(-(sz - n)/n * f1 / f0))
+          }
           res <- c(sz, Sind, Sind, Sind)
           names(res) <- c('Size', paste0('Q', .quantile[1]), 'Mean', paste0('Q', .quantile[2]))
           if (.verbose) add.pb(pb)
