@@ -1,25 +1,7 @@
 ### R code from vignette source 'tcrvignette.Rnw'
 
 ###################################################
-### code chunk number 1: tcrvignette.Rnw:80-85 (eval = FALSE)
-###################################################
-## data(human.alphabets)
-## V_ALPHA_ALPHABET
-## J_ALPHA_ALPHABET
-## V_BETA_ALPHABET
-## J_BETA_ALPHABET
-
-
-###################################################
-### code chunk number 2: tcrvignette.Rnw:91-94 (eval = FALSE)
-###################################################
-## data(mouse.alphabets)
-## V_BETA_ALPHABET
-## J_BETA_ALPHABET
-
-
-###################################################
-### code chunk number 3: tcrvignette.Rnw:101-105 (eval = FALSE)
+### code chunk number 1: tcrvignette.Rnw:81-85 (eval = FALSE)
 ###################################################
 ## data(twa)
 ## head(twa[[1]])
@@ -28,32 +10,13 @@
 
 
 ###################################################
-### code chunk number 4: tcrvignette.Rnw:136-138 (eval = FALSE)
+### code chunk number 2: tcrvignette.Rnw:89-90 (eval = FALSE)
 ###################################################
-## startmitcr('raw/TwA1_B.fastq.gz', 'mitcr/TwA1_B.txt', .file.path = '~/data/',
-##             pset = 'flex', level = 1, 'debug', .mitcr.path = '~/programs/', .mem = '8g')
+## ?genealphabets
 
 
 ###################################################
-### code chunk number 5: tcrvignette.Rnw:141-143 (eval = FALSE)
-###################################################
-## startmitcr(.file.path = '~/data/raw', pset = 'flex', level = 1, 'debug',
-##             .mitcr.path = '~/programs/', .mem = '8g')
-
-
-###################################################
-### code chunk number 6: tcrvignette.Rnw:147-153 (eval = FALSE)
-###################################################
-## # Parse file in "~/data/twb1.txt".
-## twb1 <- parse.file("~/data/twb1.txt")
-## # Parse files "~/data/twb1.txt" and "~/data/immdat2.txt".
-## twb12 <- parse.file.list(c("~/data/twb1.txt", "~/data/twb2.txt"))
-## # Parse all files in "~/data/".
-## twb <- parse.folder("~/data/")
-
-
-###################################################
-### code chunk number 7: tcrvignette.Rnw:160-163
+### code chunk number 3: tcrvignette.Rnw:119-122
 ###################################################
 library(tcR)
 data(twb)
@@ -61,27 +24,25 @@ head(twb[[1]])
 
 
 ###################################################
-### code chunk number 8: tcrvignette.Rnw:187-195
+### code chunk number 4: tcrvignette.Rnw:153-159
 ###################################################
 # Load the package.
 library(tcR)
 # Load additional packages for making this vignette.
 # Load the twins data, provided with the package.
 data(twb)
-# Load human alphabets of V-genes and J-genes, provided with the package.
-data(human.alphabets)
 mitcr.stats(twb)
 
 
 ###################################################
-### code chunk number 9: tcrvignette.Rnw:203-205
+### code chunk number 5: tcrvignette.Rnw:167-169
 ###################################################
                             # How many clones fill up approximately
 clonal.proportion(twb, 25)  # the 25% of the sum of values in 'Read.count'?
 
 
 ###################################################
-### code chunk number 10: tcrvignette.Rnw:212-215
+### code chunk number 6: tcrvignette.Rnw:176-179
 ###################################################
                           # What accounts a proportion of the top-10 clones' reads
 top.proportion(twb, 10)   # to the overall number of reads?
@@ -89,7 +50,7 @@ vis.top.proportions(twb)  # Plot this proportions.
 
 
 ###################################################
-### code chunk number 11: tcrvignette.Rnw:220-223
+### code chunk number 7: tcrvignette.Rnw:184-187
 ###################################################
                                 # What is a proportion of sequences which
                                 # have 'Read.count' <= 100 to the
@@ -97,7 +58,7 @@ tailbound.proportion(twb, 100)  # overall number of reads?
 
 
 ###################################################
-### code chunk number 12: tcrvignette.Rnw:229-234
+### code chunk number 8: tcrvignette.Rnw:193-198
 ###################################################
 imm.in <- get.inframes(twb) # Return all in-frame sequences from the 'twb'.
 
@@ -107,7 +68,7 @@ head(freq.Vb(imm.in)[,2] / freq.Vb(twb)[,2])       # Compare V-usage between in-
 
 
 ###################################################
-### code chunk number 13: tcrvignette.Rnw:237-243
+### code chunk number 9: tcrvignette.Rnw:201-207
 ###################################################
 imm.in <- get.frames(twb, 'in') # Similar to 'get.inframes(twb)'.
 
@@ -118,7 +79,7 @@ count.frames(twb, flag, 5000)   # Similar to 'count.outframes(twb, 5000)'.
 
 
 ###################################################
-### code chunk number 14: tcrvignette.Rnw:251-254
+### code chunk number 10: tcrvignette.Rnw:215-218
 ###################################################
 # Equivalent to freq.Vb(twb[[1]]) by default.
 imm1.vs <- freq.segments(twb[[1]])
@@ -126,53 +87,53 @@ head(imm1.vs)
 
 
 ###################################################
-### code chunk number 15: tcrvignette.Rnw:257-259
+### code chunk number 11: tcrvignette.Rnw:221-223
 ###################################################
 imm.vs.all <- freq.segments(twb)  # Equivalent to freq.Vb(twb) by default.
 imm.vs.all[1:10, 1:4]
 
 
 ###################################################
-### code chunk number 16: tcrvignette.Rnw:262-264
+### code chunk number 12: tcrvignette.Rnw:226-228
 ###################################################
 imm1.vj <- freq.segments.2D(twb[[1]])
 imm1.vj[1:5, 1:5]
 
 
 ###################################################
-### code chunk number 17: tcrvignette.Rnw:268-270
+### code chunk number 13: tcrvignette.Rnw:232-234
 ###################################################
 # Put ".dodge = F" to get distinct plot for every data frame in the given list.
 vis.J.usage(twb, .cast.freq = T, .main = 'twb J-usage dodge', .dodge = T)
 
 
 ###################################################
-### code chunk number 18: tcrvignette.Rnw:273-274
+### code chunk number 14: tcrvignette.Rnw:237-238
 ###################################################
 vis.J.usage(twb, .cast.freq = T, .main = 'twb J-usage column', .dodge = F, .ncol = 2)
 
 
 ###################################################
-### code chunk number 19: tcrvignette.Rnw:277-278
+### code chunk number 15: tcrvignette.Rnw:241-242
 ###################################################
 vis.V.usage(imm1.vs, .cast.freq = F, .main = 'twb[[1]] V-usage', .coord.flip = F)
 
 
 ###################################################
-### code chunk number 20: tcrvignette.Rnw:285-287
+### code chunk number 16: tcrvignette.Rnw:249-251
 ###################################################
 cmv <- data.frame(CDR3.amino.acid.sequence = c('CASSSANYGYTF', 'CSVGRAQNEQFF', 'CASSLTGNTEAFF', 'CASSALGGAGTGELFF', 'CASSLIGVSSYNEQFF'),
                   V.segments = c('TRBV4-1', 'TRBV4-1', 'TRBV4-1', 'TRBV4-1', 'TRBV4-1'), stringsAsFactors = F)
 
 
 ###################################################
-### code chunk number 21: tcrvignette.Rnw:290-291
+### code chunk number 17: tcrvignette.Rnw:254-255
 ###################################################
 cmv
 
 
 ###################################################
-### code chunk number 22: tcrvignette.Rnw:294-320
+### code chunk number 18: tcrvignette.Rnw:258-285
 ###################################################
 twb <- set.rank(twb)
 # Case 1.
@@ -188,7 +149,8 @@ head(cmv.imm.ex)
 # matching V-segments. Return ranks of found sequences.
 cmv.imm.hamm.v <- 
   find.clonotypes(twb[1:3], cmv, 'hamm', 'Rank', 
-                  .target.col = c('CDR3.amino.acid.sequence', 'V.segments'),
+                  .target.col = c('CDR3.amino.acid.sequence',
+                                  'V.segments'),
                   .verbose = F)
 head(cmv.imm.hamm.v)
 
@@ -203,7 +165,18 @@ head(cmv.imm.lev.v)
 
 
 ###################################################
-### code chunk number 23: tcrvignette.Rnw:332-345
+### code chunk number 19: tcrvignette.Rnw:292-298
+###################################################
+# data(twb)
+# Compute summary space of clones, that occupy
+# [0, .05) and [.05, 1] proportion.
+clonal.space.homeostasis(twb, c(Low = .05, High = 1))
+# Use default arguments:
+clonal.space.homeostasis(twb[[1]])
+
+
+###################################################
+### code chunk number 20: tcrvignette.Rnw:310-323
 ###################################################
 # Equivalent to intersect(twb[[1]]$CDR3.nucleotide.sequence,
 #                         twb[[2]]$CDR3.nucleotide.sequence)
@@ -221,7 +194,7 @@ vis.heatmap(intersect(twb, 'ave'), .title = 'twb - (ave)-intersection', .labs =
 
 
 ###################################################
-### code chunk number 24: tcrvignette.Rnw:352-358
+### code chunk number 21: tcrvignette.Rnw:330-336
 ###################################################
 # Get logic vector of shared elements, where
 # elements are tuples of CDR3 nucleotide sequence and corresponding V-segment
@@ -232,14 +205,14 @@ head(twb[[1]][imm.1.2, c('CDR3.amino.acid.sequence', 'V.segments')])
 
 
 ###################################################
-### code chunk number 25: tcrvignette.Rnw:364-366
+### code chunk number 22: tcrvignette.Rnw:342-344
 ###################################################
 twb.top <- top.cross(.data = twb, .n = seq(500, 10000, 500), .verbose = F, .norm = T)
 top.cross.plot(twb.top)
 
 
 ###################################################
-### code chunk number 26: tcrvignette.Rnw:373-381
+### code chunk number 23: tcrvignette.Rnw:351-359
 ###################################################
 # Evaluate the diversity of clones by the ecological diversity index.
 sapply(twb, function (x) diversity(x$Read.count))
@@ -252,7 +225,7 @@ t(sapply(twb, function (x) chao1(x$Read.count)))
 
 
 ###################################################
-### code chunk number 27: tcrvignette.Rnw:399-402
+### code chunk number 24: tcrvignette.Rnw:377-380
 ###################################################
 cols <- c('CDR3.amino.acid.sequence', 'Read.count')
 # Apply the Morisitas overlap index to the each pair of repertoires.
@@ -260,7 +233,7 @@ apply.symm(twb, function (x,y) morisitas.index(x[, cols], y[, cols]), .verbose =
 
 
 ###################################################
-### code chunk number 28: tcrvignette.Rnw:416-426
+### code chunk number 25: tcrvignette.Rnw:394-404
 ###################################################
                               # Transform "0:100" to distribution with Laplace correction 
 entropy(0:100, .laplace = 1)  # (i.e., add "1" to every value before transformation).
@@ -275,14 +248,14 @@ vis.radarlike(imm.js, .ncol = 2)
 
 
 ###################################################
-### code chunk number 29: tcrvignette.Rnw:432-434
+### code chunk number 26: tcrvignette.Rnw:410-412
 ###################################################
 pca.segments(twb)                       # Plot PCA results of V-segment usage.
 class(pca.segments(twb, .do.plot = F))  # Return object of class "prcomp"
 
 
 ###################################################
-### code chunk number 30: tcrvignette.Rnw:440-447
+### code chunk number 27: tcrvignette.Rnw:418-425
 ###################################################
 # Compute shared repertoire of amino acid CDR3 sequences and V-segments
 # which has been found in two or more people.
@@ -294,37 +267,88 @@ cosine.sharing(imm.shared)         # Compute cosing similarity on shared sequenc
 
 
 ###################################################
-### code chunk number 31: tcrvignette.Rnw:457-460
+### code chunk number 28: tcrvignette.Rnw:440-443 (eval = FALSE)
 ###################################################
-p1 <- vis.count.len(twb[[1]])
-p2 <- vis.number.count(twb[[1]])
-grid.arrange(p1, p2, ncol = 2)
+## p1 <- vis.count.len(twb[[1]])
+## p2 <- vis.number.count(twb[[1]])
+## grid.arrange(p1, p2, ncol = 2)
 
 
 ###################################################
-### code chunk number 32: tcrvignette.Rnw:480-482
+### code chunk number 29: tcrvignette.Rnw:462-464
 ###################################################
 imm.pca <- pca.segments(twb, scale. = T, .do.plot = F)
 vis.pca(imm.pca, list(AB = c(1,2), CD = c(3,4)))
 
 
 ###################################################
-### code chunk number 33: tcrvignette.Rnw:493-495
+### code chunk number 30: tcrvignette.Rnw:471-473
+###################################################
+d <- kmer.profile(c('CASLL', 'CASSQ', 'CASGL'))
+vis.logo(d)
+
+
+###################################################
+### code chunk number 31: tcrvignette.Rnw:481-484
+###################################################
+# data(twb)
+twb.space <- clonal.space.homeostasis(twb)
+vis.clonal.space(twb.space)
+
+
+###################################################
+### code chunk number 32: tcrvignette.Rnw:491-495
+###################################################
+# data(twb)
+twb.shared <- shared.repertoire(twb, .head = 1000, .verbose = F)
+G <- mutation.network(twb.shared)
+G
+
+
+###################################################
+### code chunk number 33: tcrvignette.Rnw:500-512
+###################################################
+# data(twb)
+# twb.shared <- shared.repertoire(twb, .head = 1000)
+# G <- mutation.network(twb.shared)
+G <- set.group.vector(G, "twins", list(A = c(1,2), B = c(3,4)))  # <= refactor this
+get.group.names(G, "twins", 1)
+get.group.names(G, "twins", 300)
+get.group.names(G, "twins", c(1,2,3), F)
+get.group.names(G, "twins", 300, F)
+# Because we have only two groups, we can assign more readable attribute.
+V(G)$twin.names <- get.group.names(G, "twins")
+V(G)$twin.names[1]
+V(G)$twin.names[300]
+
+
+###################################################
+### code chunk number 34: tcrvignette.Rnw:517-521
+###################################################
+# data(twb)
+# twb.shared <- shared.repertoire(twb, .head = 1000)
+# G <- mutation.network(twb.shared)
+head(mutated.neighbours(G, 1)[[1]])
+
+
+###################################################
+### code chunk number 35: tcrvignette.Rnw:532-534
 ###################################################
 head(get.kmers(twb[[1]]$CDR3.amino.acid.sequence, 100, .meat = F, .verbose = F))
 head(get.kmers(twb[[1]], .meat = T, .verbose = F))
 
 
 ###################################################
-### code chunk number 34: tcrvignette.Rnw:505-508
+### code chunk number 36: tcrvignette.Rnw:544-548
 ###################################################
 revcomp(c('AAATTT', 'ACGTTTGGA'))
-cbind(bunch.translate(twb[[1]]$CDR3.nucleotide.sequence[1:10]), twb[[1]]$CDR3.amino.acid.sequence[1:10])
+cbind(bunch.translate(twb[[1]]$CDR3.nucleotide.sequence[1:10]),
+      twb[[1]]$CDR3.amino.acid.sequence[1:10])
 gc.content(twb[[1]]$CDR3.nucleotide.sequence[1:10])
 
 
 ###################################################
-### code chunk number 35: tcrvignette.Rnw:514-520
+### code chunk number 37: tcrvignette.Rnw:554-560
 ###################################################
 codon.variants('LQ')
 translated.nucl.sequences(c('LQ', 'CASSLQ'))
